/*weerstation_3c_V10
 * temperatuur, vochtigheid, luchtdruk en windsnelheid meten en de meetwaarden op het LCD plaatsen
 * Om het display een wat rustiger aanzien te geven wordt alleen naar het display geschreven indien er veranderingen zijn in de meetwaarden
 * 
 * I2C voor LCD en BMP 280 sensor en LCD
 *
 * LCD GND en BMP GND --> GND Arduino
 * LCD VCC en BMP Vin --> 5V  Arduino
 * LCD SDA en BMP SDI --> A4  Arduino
 * LCD SCL en BMP SCK --> A5  Arduino
 * 
 * I2C aansluitingen van Arduino Uno:A4 (SDA), A5 (SCL)
 * 
 * DHT22 voor temperatuur en vochtigheid 
 * ARDUINO pen 9 voor data VAN DHT22
 * 
 * windmeting op analog A0
 * 
 */

#include <Wire.h>               // Bibliotheek voor communicatie met I2C 
#include <LiquidCrystal_I2C.h>  // Bibliotheek voor het LCD scherm
#include <Adafruit_BMP280.h>    // Bibliotheek voor de BMP 280 sensor
#include <DHT.h>                // DHT sensor bibliotheek toevoegen

LiquidCrystal_I2C lcd(0x27,20,4);   // start LCD scherm en lcd is gebruiksnaam
Adafruit_BMP280 bmp;                //bmp is nu de gebruiksnaam voor de druk sensor
DHT sensor_dht(9,DHT22);            // onze sensor heet nu: sensor_dht

float luchtdruk, temperatuur, vochtigheid; // variablen
int windmeting =1;

byte graden[8] = {             // graden teken
  B00010,
  B00101,
  B00101,
  B00010,
  B00000,
  B00000,
  B00000,
  B00000
};

void emptyline(){              // lege lijn routine
  lcd.print ("                    ");
}

void setup() {
  lcd.init();                  // initialiseer het LCD scherm
  lcd.backlight();             // zet de backlight aan
  lcd.createChar(0,graden);    // het symbool graden staat nu op positie 0 
  bmp.begin();                 // start de bmp sensor
  sensor_dht.begin();          // start de dht sensor
  delay(1000);
  lcd.clear();                 // wis het scherm 
}
 
void loop() {
  //lees de temperatuur, vochtigheid, luchtdruk en windsnelheid uit en vergelijk die met de vorige waarde
  
  if (temperatuur != sensor_dht.readTemperature())
  {
    temperatuur = sensor_dht.readTemperature();
    lcd.setCursor(0, 0);         // zet de cursor op positie 1, regel 1
    emptyline();
    lcd.setCursor(0, 0);         // zet de cursor op positie 1, regel 1
    lcd.print ("Temp : "); lcd.print(temperatuur,1); lcd.write(0); lcd.print ("C");
  }

  if (vochtigheid != sensor_dht.readHumidity())
  {
    vochtigheid = sensor_dht.readHumidity();
    lcd.setCursor(0, 1);         // zet de cursor op positie 1, regel 2
    emptyline();
    lcd.setCursor(0, 1);         // zet de cursor op positie 1, regel 2
    lcd.print ("Vocht: "); lcd.print(vochtigheid,1); lcd.print (" % ");
  }
  
  if (round(luchtdruk) != round(bmp.readPressure()/100))
  {
    luchtdruk = bmp.readPressure()/100;
    lcd.setCursor(0, 2);         // zet de cursor op positie 1, regel 3
    emptyline();
    lcd.setCursor(0, 2);         // zet de cursor op positie 1, regel 3
    lcd.print("Luchtdruk: "); lcd.print (round(luchtdruk)); lcd.print (" hPa");                 
  }

  if (windmeting != analogRead (A0))
  {
    windmeting = analogRead(A0);
    lcd.setCursor(0, 3);         // zet de cursor op positie 1, regel 4
    emptyline();
    lcd.setCursor(0, 3);         // zet de cursor op positie 1, regel 4
    lcd.print ("Wind: ");
      if (windmeting > 900){
        lcd.print ("storm !!");
      }
      else if (windmeting > 500){
        lcd.print ("hard");
      }
      else if (windmeting > 20){
        lcd.print ("matig");
      }
      else {
        lcd.print ("geen/weinig");
      }
  }
       
  delay(1000);
}
